@@ -6,10 +6,18 @@
 package org.wildfly.extension.opentelemetry;
 
 import static org.jboss.as.weld.Capabilities.WELD_CAPABILITY_NAME;
+import static org.wildfly.extension.opentelemetry.OpenTelemetryConfigurationConstants.DEFAULT_BATCH_DELAY;
+import static org.wildfly.extension.opentelemetry.OpenTelemetryConfigurationConstants.DEFAULT_EXPORT_TIMEOUT;
+import static org.wildfly.extension.opentelemetry.OpenTelemetryConfigurationConstants.DEFAULT_MAX_EXPORT_BATCH_SIZE;
+import static org.wildfly.extension.opentelemetry.OpenTelemetryConfigurationConstants.DEFAULT_MAX_QUEUE_SIZE;
+import static org.wildfly.extension.opentelemetry.OpenTelemetryConfigurationConstants.EXPORTER_JAEGER;
+import static org.wildfly.extension.opentelemetry.OpenTelemetryConfigurationConstants.EXPORTER_OTLP;
 import static org.wildfly.extension.opentelemetry.OpenTelemetryConfigurationConstants.GROUP_EXPORTER;
 import static org.wildfly.extension.opentelemetry.OpenTelemetryConfigurationConstants.GROUP_SAMPLER;
 import static org.wildfly.extension.opentelemetry.OpenTelemetryConfigurationConstants.GROUP_SPAN_PROCESSOR;
 import static org.wildfly.extension.opentelemetry.OpenTelemetryConfigurationConstants.OPENTELEMETRY_CAPABILITY_NAME;
+import static org.wildfly.extension.opentelemetry.OpenTelemetryConfigurationConstants.SPAN_PROCESSOR_BATCH;
+import static org.wildfly.extension.opentelemetry.OpenTelemetryExtensionLogger.OTEL_LOGGER;
 
 import java.util.Arrays;
 import java.util.Collection;
@@ -18,14 +26,21 @@ import java.util.function.Supplier;
 
 import io.smallrye.opentelemetry.api.OpenTelemetryConfig;
 import org.jboss.as.controller.AttributeDefinition;
+import org.jboss.as.controller.OperationContext;
 import org.jboss.as.controller.OperationFailedException;
+import org.jboss.as.controller.OperationStepHandler;
+import org.jboss.as.controller.PathAddress;
 import org.jboss.as.controller.PersistentResourceDefinition;
 import org.jboss.as.controller.ReloadRequiredRemoveStepHandler;
+import org.jboss.as.controller.ReloadRequiredWriteAttributeHandler;
 import org.jboss.as.controller.SimpleAttributeDefinition;
 import org.jboss.as.controller.SimpleAttributeDefinitionBuilder;
 import org.jboss.as.controller.SimpleResourceDefinition;
 import org.jboss.as.controller.capability.RuntimeCapability;
+import org.jboss.as.controller.logging.ControllerLogger;
 import org.jboss.as.controller.operations.validation.StringAllowedValuesValidator;
+import org.jboss.as.controller.registry.AttributeAccess;
+import org.jboss.as.controller.registry.ManagementResourceRegistration;
 import org.jboss.dmr.ModelNode;
 import org.jboss.dmr.ModelType;
 
@@ -35,11 +50,6 @@ import org.jboss.dmr.ModelType;
 
 class OpenTelemetrySubsystemDefinition extends PersistentResourceDefinition {
     static final String OPENTELEMETRY_MODULE = "org.wildfly.extension.opentelemetry";
-    private static final String[] ALLOWED_EXPORTERS = {"jaeger", "otlp"};
-    private static final String[] ALLOWED_SAMPLERS = {"on", "off", "ratio"};
-    private static final String[] ALLOWED_SPAN_PROCESSORS = {"batch", "simple"};
-
-    public static final String DEFAULT_ENDPOINT = "http://localhost:14250";
     public static final String API_MODULE = "org.wildfly.extension.opentelemetry-api";
     public static final String[] EXPORTED_MODULES = {
             "io.opentelemetry.api",
@@ -57,7 +67,6 @@ class OpenTelemetrySubsystemDefinition extends PersistentResourceDefinition {
     public static final WildFlyOpenTelemetryConfigSupplier CONFIG_SUPPLIER = new WildFlyOpenTelemetryConfigSupplier();
     static final RuntimeCapability<WildFlyOpenTelemetryConfigSupplier> OPENTELEMETRY_CONFIG_CAPABILITY =
             RuntimeCapability.Builder.of(OPENTELEMETRY_MODULE + ".config", false, CONFIG_SUPPLIER).build();
-    @Deprecated
     public static final SimpleAttributeDefinition SERVICE_NAME = SimpleAttributeDefinitionBuilder
             .create(OpenTelemetryConfigurationConstants.SERVICE_NAME, ModelType.STRING, true)
             .setAllowExpression(true)
@@ -69,8 +78,8 @@ class OpenTelemetrySubsystemDefinition extends PersistentResourceDefinition {
             .setAllowExpression(true)
             .setAttributeGroup(GROUP_EXPORTER)
             .setXmlName(OpenTelemetryConfigurationConstants.TYPE)
-            .setDefaultValue(new ModelNode("jaeger"))
-            .setValidator(new StringAllowedValuesValidator(ALLOWED_EXPORTERS))
+            .setDefaultValue(new ModelNode(EXPORTER_OTLP))
+            .setValidator(new StringAllowedValuesValidator(OpenTelemetryConfigurationConstants.ALLOWED_EXPORTERS))
             .setRestartAllServices()
             .build();
 
@@ -79,7 +88,7 @@ class OpenTelemetrySubsystemDefinition extends PersistentResourceDefinition {
             .setAllowExpression(true)
             .setAttributeGroup(GROUP_EXPORTER)
             .setRestartAllServices()
-            .setDefaultValue(new ModelNode(DEFAULT_ENDPOINT))
+            .setDefaultValue(new ModelNode(OpenTelemetryConfigurationConstants.DEFAULT_OTLP_ENDPOINT))
             .build();
 
     @Deprecated
@@ -89,8 +98,8 @@ class OpenTelemetrySubsystemDefinition extends PersistentResourceDefinition {
             .setXmlName(OpenTelemetryConfigurationConstants.TYPE)
             .setAttributeGroup(GROUP_SPAN_PROCESSOR)
             .setRestartAllServices()
-            .setDefaultValue(new ModelNode("batch"))
-            .setValidator(new StringAllowedValuesValidator(ALLOWED_SPAN_PROCESSORS))
+            .setDefaultValue(new ModelNode(SPAN_PROCESSOR_BATCH))
+            .setValidator(new StringAllowedValuesValidator(OpenTelemetryConfigurationConstants.ALLOWED_SPAN_PROCESSORS))
             .build();
 
     public static final SimpleAttributeDefinition BATCH_DELAY = SimpleAttributeDefinitionBuilder
@@ -98,7 +107,7 @@ class OpenTelemetrySubsystemDefinition extends PersistentResourceDefinition {
             .setAllowExpression(true)
             .setAttributeGroup(GROUP_SPAN_PROCESSOR)
             .setRestartAllServices()
-            .setDefaultValue(new ModelNode(5000))
+            .setDefaultValue(new ModelNode(DEFAULT_BATCH_DELAY))
             .build();
 
     public static final SimpleAttributeDefinition MAX_QUEUE_SIZE = SimpleAttributeDefinitionBuilder
@@ -106,7 +115,7 @@ class OpenTelemetrySubsystemDefinition extends PersistentResourceDefinition {
             .setAllowExpression(true)
             .setAttributeGroup(GROUP_SPAN_PROCESSOR)
             .setRestartAllServices()
-            .setDefaultValue(new ModelNode(2048))
+            .setDefaultValue(new ModelNode(DEFAULT_MAX_QUEUE_SIZE))
             .build();
 
     public static final SimpleAttributeDefinition MAX_EXPORT_BATCH_SIZE = SimpleAttributeDefinitionBuilder
@@ -114,7 +123,7 @@ class OpenTelemetrySubsystemDefinition extends PersistentResourceDefinition {
             .setAllowExpression(true)
             .setAttributeGroup(GROUP_SPAN_PROCESSOR)
             .setRestartAllServices()
-            .setDefaultValue(new ModelNode(512))
+            .setDefaultValue(new ModelNode(DEFAULT_MAX_EXPORT_BATCH_SIZE))
             .build();
 
     public static final SimpleAttributeDefinition EXPORT_TIMEOUT = SimpleAttributeDefinitionBuilder
@@ -122,7 +131,7 @@ class OpenTelemetrySubsystemDefinition extends PersistentResourceDefinition {
             .setAllowExpression(true)
             .setAttributeGroup(GROUP_SPAN_PROCESSOR)
             .setRestartAllServices()
-            .setDefaultValue(new ModelNode(30000))
+            .setDefaultValue(new ModelNode(DEFAULT_EXPORT_TIMEOUT))
             .build();
 
     public static final SimpleAttributeDefinition SAMPLER = SimpleAttributeDefinitionBuilder
@@ -130,12 +139,12 @@ class OpenTelemetrySubsystemDefinition extends PersistentResourceDefinition {
             .setAllowExpression(true)
             .setXmlName(OpenTelemetryConfigurationConstants.TYPE)
             .setAttributeGroup(GROUP_SAMPLER)
-            .setValidator(new StringAllowedValuesValidator(ALLOWED_SAMPLERS))
+            .setValidator(new StringAllowedValuesValidator(OpenTelemetryConfigurationConstants.ALLOWED_SAMPLERS))
             .setRestartAllServices()
             .build();
 
     public static final SimpleAttributeDefinition RATIO = SimpleAttributeDefinitionBuilder
-            .create(OpenTelemetryConfigurationConstants.RATIO, ModelType.DOUBLE, true)
+            .create(OpenTelemetryConfigurationConstants.SAMPLER_RATIO, ModelType.DOUBLE, true)
             .setAllowExpression(true)
             .setAttributeGroup(GROUP_SAMPLER)
             .setValidator((parameterName, value) -> {
@@ -163,11 +172,34 @@ class OpenTelemetrySubsystemDefinition extends PersistentResourceDefinition {
         );
     }
 
+    static void validateExporter(OperationContext context, String exporter) throws OperationFailedException {
+
+        if (EXPORTER_JAEGER.equals(exporter)) {
+            if (context.isNormalServer()) {
+                context.setRollbackOnly();
+                throw new OperationFailedException(OTEL_LOGGER.jaegerIsNoLongerSupported());
+            } else {
+                OTEL_LOGGER.warn(OTEL_LOGGER.jaegerIsNoLongerSupported());
+            }
+        }
+    }
+
     @Override
     public Collection<AttributeDefinition> getAttributes() {
         return Arrays.asList(ATTRIBUTES);
     }
 
+    @Override
+    public void registerAttributes(ManagementResourceRegistration resourceRegistration) {
+        OperationStepHandler handler = new ValidateExporterWriteAttributeHandler();
+        for (AttributeDefinition attr : getAttributes()) {
+            if(!attr.getFlags().contains(AttributeAccess.Flag.RESTART_ALL_SERVICES)) {
+                throw ControllerLogger.ROOT_LOGGER.attributeWasNotMarkedAsReloadRequired(attr.getName(), resourceRegistration.getPathAddress());
+            }
+            resourceRegistration.registerReadWriteAttribute(attr, null, handler);
+        }
+    }
+
     static class WildFlyOpenTelemetryConfigSupplier implements Supplier<OpenTelemetryConfig>, Consumer<OpenTelemetryConfig> {
         private OpenTelemetryConfig config;
         @Override
@@ -180,4 +212,18 @@ class OpenTelemetrySubsystemDefinition extends PersistentResourceDefinition {
             return config;
         }
     }
+
+    private static class ValidateExporterWriteAttributeHandler extends ReloadRequiredWriteAttributeHandler {
+
+        @Override
+        protected boolean applyUpdateToRuntime(OperationContext context, ModelNode operation, String attributeName, ModelNode resolvedValue, ModelNode currentValue, HandbackHolder<Void> voidHandback) throws OperationFailedException {
+            AttributeDefinition attributeDefinition = context.getResourceRegistration().getAttributeAccess(PathAddress.EMPTY_ADDRESS, attributeName).getAttributeDefinition();
+            if (EXPORTER.equals(attributeDefinition)) {
+                // Need to validate 'jaeger' isn't used in a non-admin-only server
+                validateExporter(context, resolvedValue.asString());
+            }
+
+            return super.applyUpdateToRuntime(context, operation, attributeName, resolvedValue, currentValue, voidHandback);
+        }
+    }
 }
